diff src/upnp.h @ 11501:9563b768e8e2

[gaim-migrate @ 13746] Doxygen fixes. committer: Tailor Script <tailor@pidgin.im>
author Richard Laager <rlaager@wiktel.com>
date Sun, 11 Sep 2005 03:58:13 +0000
parents d3755a7ddd82
children 8e3b85fe4a55
line wrap: on
line diff
--- a/src/upnp.h	Sun Sep 11 02:58:03 2005 +0000
+++ b/src/upnp.h	Sun Sep 11 03:58:13 2005 +0000
@@ -48,8 +48,6 @@
  * contains the WANIPConnection service that will allow us to recieve the
  * public IP address of the IGD, and control it for forwarding ports.
  *
- * @param void
- *
  * @return The control URL for the IGD we'll use to use the IGD services
  */
 GaimUPnPControlInfo* gaim_upnp_discover(void);
@@ -61,7 +59,7 @@
  * network, so when getting the network IP, instead of returning the
  * local network IP, the public IP is retrieved.
  *
  * @param controlURL The control URL retrieved from gaim_upnp_discover.
  *
  * @return The IP address of the network, or NULL if something went wrong
  */
@@ -73,7 +71,7 @@
  * this gaim client. Essentially, this function takes care of the port
  * forwarding so things like file transfers can work behind NAT firewalls
  *
  * @param controlURL The control URL retrieved from gaim_upnp_discover.
  * @param portMap The port to map to this client
  * @param protocol The protocol to map, either "TCP" or "UDP"
  *
@@ -89,14 +87,14 @@
  * port forwarding after they have completed a connection so another client on
  * the local network can take advantage of the port forwarding
  *
  * @param controlURL The control URL retrieved from gaim_upnp_discover.
  * @param portMap The port to delete the mapping for
  * @param protocol The protocol to map to. Either "TCP" or "UDP"
  *
  * @return TRUE if success, FALSE if something went wrong.
  */
 gboolean 
-gaim_upnp_remove_port_mapping(const GaimUPnPControlInfo* controlURL, 
+gaim_upnp_remove_port_mapping(const GaimUPnPControlInfo* controlInfo,
                               unsigned short portMap,
                               const gchar* protocol);
 /*@}*/
@@ -61,7 +59,7 @@
  * local network IP, the public IP is retrieved.
  *
- * @param controlURL The control URL retrieved from gaim_upnp_discover.
+ * @param controlInfo The control URL retrieved from gaim_upnp_discover.
  *
  * @return The IP address of the network, or NULL if something went wrong
@@ -73,7 +71,7 @@
  * forwarding so things like file transfers can work behind NAT firewalls
  *
- * @param controlURL The control URL retrieved from gaim_upnp_discover.
+ * @param controlInfo The control URL retrieved from gaim_upnp_discover.
  * @param portMap The port to map to this client
  * @param protocol The protocol to map, either "TCP" or "UDP"
@@ -89,14 +87,14 @@
  * the local network can take advantage of the port forwarding
  *
- * @param controlURL The control URL retrieved from gaim_upnp_discover.
+ * @param controlInfo The control URL retrieved from gaim_upnp_discover.
  * @param portMap The port to delete the mapping for
  * @param protocol The protocol to map to. Either "TCP" or "UDP"